@@ -246,7 +246,9 @@ css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar *
 			}
 		}
 		else if (c > 0x80) {
-			g_error ("support unicode!\n");
+			g_warning ("support unicode!\n");
+			g_free (buffer);
+			return -1;
 		}
 		else {
 			g_free (buffer);
