@@ -128,6 +128,13 @@ repaint_sel (gpointer data, gpointer user_data)
 	HtmlBox  *box  = HTML_BOX (data);
 	gint x, y;
 
+	if (!box->dom_node)
+	/*
+         * We may be destroying the node. In any case the underlying node
+	 * has been deleted.
+	 */
+           	return;
+
 	x = html_box_get_absolute_x (box);
 	y = html_box_get_absolute_y (box);
 
