@@ -224,7 +224,8 @@ html_view_relayout (HtmlView *view)
 	}
 
 	if (GTK_WIDGET_HAS_FOCUS (view)) {
-		if (view->document->focus_element == NULL) {
+		if (view->document->focus_element == NULL &&
+		    view->document->dom_document) {
 			html_document_update_focus_element (view->document, html_focus_iterator_next_element (view->document->dom_document, NULL));
 			html_view_focus_element (view);
 		}
